@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2015 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2016 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -25,7 +25,7 @@ vnonlinear.control <- function(save.weights = TRUE, ...) {
 subset.lohi <- function(xvec, yvec,
                         probs.x = c(0.15, 0.85),
                         type = c("median", "wtmean", "unwtmean"),
-                        wtvec = rep(1, len = length(xvec))) {
+                        wtvec = rep_len(1, length(xvec))) {
 
 
   if (!is.Numeric(probs.x, length.arg = 2))
@@ -131,9 +131,12 @@ micmen.control <- function(save.weights = TRUE, ...) {
             "Variance: constant"),
 
   constraints = eval(substitute(expression({
-    constraints <- cm.zero.VGAM(constraints, x = x, .zero , M = 2)
+    constraints <- cm.zero.VGAM(constraints, x = x, .zero , M = M,
+                                predictors.names = predictors.names,
+                                M1 = 2)
   }), list( .zero = zero))),
 
+
   deviance = function(mu, y, w, residuals = FALSE, eta, extra = NULL) {
     M <- if (is.matrix(y)) ncol(y) else 1
     if (residuals) {
@@ -143,6 +146,20 @@ micmen.control <- function(save.weights = TRUE, ...) {
     }
   },
 
+
+  infos = eval(substitute(function(...) {
+    list(M1 = 2,
+         Q1 = 1,
+         expected = TRUE,
+         multipleResponses = FALSE,
+         parameters.names = c("theta1", "theta2"),
+         link1    = .link1 ,
+         link2    = .link2 ,
+         zero = .zero )
+  }, list( .zero = zero,
+           .link1 = link1, .link2 = link2
+         ))),
+
   initialize = eval(substitute(expression({
 
 
@@ -195,8 +212,8 @@ micmen.control <- function(save.weights = TRUE, ...) {
       if (length( .init2 )) init2 <- .init2
 
       etastart <- cbind(
-          rep(theta2eta(init1, .link1 , earg = .earg1 ), len = n),
-          rep(theta2eta(init2, .link2 , earg = .earg2 ), len = n))
+          rep_len(theta2eta(init1, .link1 , earg = .earg1 ), n),
+          rep_len(theta2eta(init2, .link2 , earg = .earg2 ), n))
     } else {
       stop("cannot handle 'etastart' or 'mustart'")
     }
@@ -409,8 +426,11 @@ skira.control <- function(save.weights = TRUE, ...) {
             namesof("theta1", link1, earg = earg1), ", ",
             namesof("theta2", link2, earg = earg2)),
   constraints = eval(substitute(expression({
-    constraints <- cm.zero.VGAM(constraints, x = x, .zero , M = 2)
+    constraints <- cm.zero.VGAM(constraints, x = x, .zero , M = M,
+                                predictors.names = predictors.names,
+                                M1 = 2)
   }), list( .zero = zero ))),
+
   deviance = function(mu, y, w, residuals = FALSE, eta, extra = NULL) {
     M <- if (is.matrix(y))
       ncol(y) else 1
@@ -420,6 +440,20 @@ skira.control <- function(save.weights = TRUE, ...) {
       ResSS.vgam(y - mu, w, M = M)
     }
   },
+
+  infos = eval(substitute(function(...) {
+    list(M1 = 2,
+         Q1 = 1,
+         expected = TRUE,
+         multipleResponses = FALSE,
+         parameters.names = c("theta1", "theta2"),
+         link1    = .link1 ,
+         link2    = .link2 ,
+         zero = .zero )
+  }, list( .zero = zero,
+           .link1 = link1, .link2 = link2
+         ))),
+
   initialize = eval(substitute(expression({
 
  warning("20101105; need to fix a bug in the signs of initial vals")
@@ -518,8 +552,8 @@ skira.control <- function(save.weights = TRUE, ...) {
       if (length( .init1 )) init1 <- .init1
       if (length( .init2 )) init2 <- .init2
       etastart <- cbind(
-          rep(theta2eta(init1, .link1 , earg = .earg1 ), len = n),
-          rep(theta2eta(init2, .link2 , earg = .earg2 ), len = n))
+          rep_len(theta2eta(init1, .link1 , earg = .earg1 ), n),
+          rep_len(theta2eta(init2, .link2 , earg = .earg2 ), n))
     } else {
       stop("cannot handle 'etastart' or 'mustart'")
     }
